# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html),
and is generated by [Changie](https://github.com/miniscruff/changie).


## 1.1.9 - 2025-01-17
### Added
* best effort pass through of unrendered extra inheritables
### Fixed
* Only inject node description if yaml description is empty
* Correct path matching for positional args

## 1.1.8 - 2025-01-08
### Changed
* more string dumping improvements including canonicalization by default and dynamic determination of flow style based on line breaks or len vs config width

## 1.1.7 - 2025-01-05
### Added
* better default str dumping for multiline strings in dbt yamls
* working dbt proxy speaking mysql protocol, part of an experiment but could be useful as is
### Changed
* force dbt 1.9 compat via uv dep override, we need to keep streamlit pinned to where it is to to a breaking change which affects our material UI components

## 1.1.6 - 2025-01-04

### Added

* Seeds now require a `+dbt-osmosis: <path>` in `dbt_project.yml`, or dbt-osmosis raises an exception.
* Added a pluggy-based plugin system for custom fuzzy matching of column names (prefix, case transforms, etc.).
* Configuration can now be set at multiple levels (folder-level, node-level, column-level), merging with global defaults.
* Added `--synthesize` to `refactor`/`document` commands for auto-generating missing docs via OpenAI.
* Added `--skip-add-source-columns` to skip adding columns to source YAMLs specifically (helpful for wide or rapidly changing source schemas).
* A Python API for **Transform Operations** and **Transform Pipelines** that make them nice to use in custom automations built on top of dbt-osmosis.
* Enhanced API for chaining manifest and node transformers, enabling more modular and flexible operations.
* Added logging improvements and auto-apply parameters for better usability and traceability.
* Introduced support for environment variables in discovery functions, improving dynamic configuration options.
* Resolved sorting issues in YAML column ordering, allowing directory/node-level configurations for alphabetical sorting.

### Changed

* Migrated `vars.dbt-osmosis` structure to nest sources under `sources:` key (e.g., `vars: dbt-osmosis: sources:`).
* Renamed flags:
  * `--char-length` → `--string-length`
  * `--numeric-precision` → `--numeric-precision-and-scale`
  * `--catalog-file` → `--catalog-path`
* Organized and refactored prompts for file moves unless `--auto-apply` is passed.
* Child docs no longer overwrite existing downstream descriptions unless `--force-inherit-descriptions` is used. The old `osmosis_keep_description` is deprecated.
* Child meta merges with upstream meta instead of overwriting it, giving precedence to the node being merged into for conflicting keys.
* Refactored the entire package to follow a more hybrid functional programming (FP) and Go-style approach, emphasizing simplicity and functions operating on pure data structures.
* Improved LLM context handling with additional test coverage and enhanced input structure.
* Topological sorting now ensures consistent operation order during `_iter` traversal.

### Removed

* The `diff` code and command are removed.
* The dbt bottle server was removed.
* The vendored dbt core interface was removed, folding into the core library, reducing unnecessary complexity and dependencies.
* Deprecated less-maintained SQLite adapter in favor of DuckDB, which provides significantly better performance and support.

## 0.13.2 - 2024-06-17
### Added
* support char length and numeric precision options
### Fixed
* set env vars as invocation context for dbt>=1.8
* dead code in get_task
* set macro context generator for dbt>=1.8
* add second pos arg for get_task_cls in dbt>=1.8
* missing args on project arg mock

## 0.13.1 - 2024-06-14
### Fixed
* Missing second argument for BaseAdapter in dbt-core 1.8+

## 0.13.0 - 2024-06-12
### Added
* Test with multiple version of dbt core
* Compatibility with dbt core 1.6+
* Test on multiple python versions
### Changed
* Pre-commit hooks updates
* Imports refactored for dbt 1.8
### Fixed
* Extend cache ttl for long running processes to ensure we dont recycle db connection

## 0.12.10 - 2024-05-05
### Added
* New --add-inheritance-for-specified-keys flag to allow inheriting arbitrary keys from model node

## 0.12.9 - 2024-04-07
### Changed
* update setup python and checkout action in ci workflow
### Removed
* duplicate setting for hadolint
### Fixed
* intialize n_cols_added var
* skip add data types flag application was inverted

## 0.12.8 - 2024-03-29
### Added
* Add a `--skip-add-data-types` flag

## 0.12.7 - 2024-03-28
### Added
* Add a --use-unrendered-descriptions flag which allows doc block propagation
### Removed
* drop pydantic dependency
### Fixed
* fix a race condition during project restructure causing keyerrors

## 0.12.6 - 2024-01-17
### Added
* Read column metadata from catalog even if source is specified

## 0.12.5 - 2024-01-07
### Added
* more typing to improve code readability
* Keep column description if meta.osmosis_keep_description is True
* Add identifier property support for source entity type. (#114)
* feat: load column description from db
* enable setting encoding in yaml handler via env var
### Fixed
* add sources only if available
* Get the data_type and comment of child column instead of its parent

## 0.12.4 - 2023-09-22
### Added
* enabled more pre-commit hooks
### Fixed
* use yaml for deserializing vars flag

## 0.12.3 - 2023-09-20
### Fixed
* Hotfix for incorrect var name

## 0.12.2 - 2023-09-20
### Added
* Introduced precommit
* Added --profile argument to select specific profile
* added --vars option to set vars during execution
* Propagate column data types in separate code path
* Added reproducible dev environment using nix flakes
* Refactor to make testing much easier plus added basic tests for inheritance
### Changed
* No longer homegenize yamls, remove empty sources or models keys

## 0.12.1 - 2023-09-06
### Added
* blacklist feature via reserved _blacklist key in dbt-osmosis key under vars
### Fixed
* database variable referenced before assignment if using string syntax
* column metadata could pass name both in kwarg and explicitly which is incorrect
* attempt to fix streamlit app

## 0.12.0 - 2023-09-03
### Added
* managed sources key can now include database
* progenitor information can now be added to column meta as a key capable of identifying the source of a column based on its furthest upstream same name reference
### Fixed
* Relax streamlit version requirements to make compatible with dbt core 1.6 and bigquery libs dependent on protobuf
* fix source key not parsing dicts as an input as stated in readme

## 0.11.23 - 2023-08-11
### Added
* New flags --skip-add-tags and --skip-merge-meta for yaml
* Column lineage will match on camel case to snake case converted strings

## 0.11.21 - 2023-06-14
### Fixed
* Followup fix for column case sensitivity, community contribution

## 0.11.19 - 2023-05-11
### Added
* You can now skip columns being added to yaml files by default via flag. Useful if you have massive sources and are purposefully not documenting much of them. The flag is called --skip-add-columns on all yaml subcommands.
### Changed
* Relaxed python contraint to include py311
### Fixed
* Fixed case sensitivity in snowflake during column reordering

## 0.11.17 - 2023-04-03
### Fixed
* Added attr check to lineage function to ensure safe access to depends_on

## 0.11.16 - 2023-03-31
### Fixed
* Ensure we use regular jinja parsing and NOT experimental parsing or rust parsing because both of these involve randomized correctness tests sampled from user projects in the wild if not explicitly disable and both seem to want to pickle an object with an RLock, probably an adapter instance

## 0.11.15 - 2023-03-30
### Fixed
* fix --register-project flag on server serve codepath

## 0.11.14 - 2023-03-30
### Fixed
* Feed now uses state making the entire app more snappy and resolving race conditions

## 0.11.12 - 2023-03-30
### Added
* Rebuilt the dbt osmosis workbench with a complete overhaul

## 0.11.11 - 2023-03-28
### Fixed
* Ensure pre-commit hook returns non-zero on file mutations

## 0.11.10 - 2023-03-28
### Added
* Support for positional selectors based simply on file path or model name to greatly simplify running on subsets of the DAG

## 0.11.9 - 2023-03-28
### Fixed
* Fix for schema path resolve call via ternary check

## 0.11.8 - 2023-03-27
### Added
* Support for automated reordering of yaml columns to match database

## 0.11.6 - 2023-03-26
### Fixed
* Support for bigquery record columns

## 0.6.4 - 2022-08-12
### Changed
* --pk is not longer required for diff command as we will use a hash of all columns as a fallback

## 0.6.3 - 2022-08-10
### Changed
* Ensure default entrypoint disables magic since we use triple quoted strings to document variables in the app

## 0.6.2 - 2022-08-06
### Fixed
* Fixed profile swapping functionality

## 0.6.1 - 2022-08-06
### Added
* Added 2 RSS feeds to the bottom for easy access reading 🤓
### Changed
* Moved adapters to extras, not needed to install the project but used internally for development and testing
### Removed
* Removed unused function and hash funcs from app code
### Fixed
* Fixed a bug in profiles and project directories sharing a state var name
* Removed -m argumaent from workbench entrypoint through executable

## 0.5.10 - 2022-08-05
### Added
* diff has multiple outputs including table (stdout), csv (disk), or chart/bar (stdout)
### Changed
* data git diff now defaults to dbt_osmosis schema
* data git diff now uses an md5 hash of compiled sql so we dont rerun unless model has changed

## 0.5.9 - 2022-08-05
### Added
* Start using changie for changelog management
